@@ -150,29 +150,29 @@ pub(crate) fn default_tokio_dependency() -> Dependency {
 pub(crate) fn default_pipebase_dependency() -> Dependency {
     DependencyBuilder::new()
         .name("pipebase".to_owned())
-        .version("0.1.8".to_owned())
+        .version("0.1.9".to_owned())
         .modules(vec!["pipebase::prelude::*".to_owned()])
         .build()
 }
 
-pub(crate) fn default_log_dependency() -> Dependency {
+pub(crate) fn default_tracing_dependency() -> Dependency {
     DependencyBuilder::new()
-        .name("log".to_owned())
-        .version("0.4.14".to_owned())
+        .name("tracing".to_owned())
+        .version("0.1".to_owned())
         .build()
 }
 
-pub(crate) fn default_env_log_dependency() -> Dependency {
+pub(crate) fn default_tracing_subscriber_dependency() -> Dependency {
     DependencyBuilder::new()
-        .name("env_logger".to_owned())
-        .version("0.8.4".to_owned())
+        .name("tracing-subscriber".to_owned())
+        .version("0.2".to_owned())
         .build()
 }
 
 pub(crate) fn default_avro_dependency() -> Dependency {
     DependencyBuilder::new()
         .name("pipeavro".to_owned())
-        .version("0.1.0".to_owned())
+        .version("0.1.3".to_owned())
         .modules(vec!["pipeavro::*".to_owned()])
         .build()
 }
@@ -180,7 +180,7 @@ pub(crate) fn default_avro_dependency() -> Dependency {
 pub(crate) fn default_cql_dependency() -> Dependency {
     DependencyBuilder::new()
         .name("pipecql".to_owned())
-        .version("0.2.0".to_owned())
+        .version("0.2.1".to_owned())
         .modules(vec!["pipecql::*".to_owned()])
         .build()
 }
@@ -188,7 +188,7 @@ pub(crate) fn default_cql_dependency() -> Dependency {
 pub(crate) fn default_csv_dependency() -> Dependency {
     DependencyBuilder::new()
         .name("pipecsv".to_owned())
-        .version("0.1.2".to_owned())
+        .version("0.1.4".to_owned())
         .modules(vec!["pipecsv::*".to_owned()])
         .build()
 }
@@ -196,7 +196,7 @@ pub(crate) fn default_csv_dependency() -> Dependency {
 pub(crate) fn default_json_dependency() -> Dependency {
     DependencyBuilder::new()
         .name("pipejson".to_owned())
-        .version("0.1.3".to_owned())
+        .version("0.1.5".to_owned())
         .modules(vec!["pipejson::*".to_owned()])
         .build()
 }
@@ -204,7 +204,7 @@ pub(crate) fn default_json_dependency() -> Dependency {
 pub(crate) fn default_kafka_dependency() -> Dependency {
     DependencyBuilder::new()
         .name("pipekafka".to_owned())
-        .version("0.2.0".to_owned())
+        .version("0.2.2".to_owned())
         .modules(vec!["pipekafka::*".to_owned()])
         .build()
 }
@@ -212,7 +212,7 @@ pub(crate) fn default_kafka_dependency() -> Dependency {
 pub(crate) fn default_kube_dependency() -> Dependency {
     DependencyBuilder::new()
         .name("pipekube".to_owned())
-        .version("0.1.2".to_owned())
+        .version("0.1.4".to_owned())
         .modules(vec!["pipekube::*".to_owned()])
         .build()
 }
@@ -220,7 +220,7 @@ pub(crate) fn default_kube_dependency() -> Dependency {
 pub(crate) fn default_mysql_dependency() -> Dependency {
     DependencyBuilder::new()
         .name("pipemysql".to_owned())
-        .version("0.2.0".to_owned())
+        .version("0.2.1".to_owned())
         .modules(vec!["pipemysql::*".to_owned()])
         .build()
 }
@@ -228,7 +228,7 @@ pub(crate) fn default_mysql_dependency() -> Dependency {
 pub(crate) fn default_psql_dependency() -> Dependency {
     DependencyBuilder::new()
         .name("pipepsql".to_owned())
-        .version("0.2.0".to_owned())
+        .version("0.2.1".to_owned())
         .modules(vec!["pipepsql::*".to_owned()])
         .build()
 }
@@ -236,7 +236,7 @@ pub(crate) fn default_psql_dependency() -> Dependency {
 pub(crate) fn default_redis_dependency() -> Dependency {
     DependencyBuilder::new()
         .name("piperedis".to_owned())
-        .version("0.1.3".to_owned())
+        .version("0.1.5".to_owned())
         .modules(vec!["piperedis::*".to_owned()])
         .build()
 }
@@ -244,7 +244,7 @@ pub(crate) fn default_redis_dependency() -> Dependency {
 pub(crate) fn default_reqwest_dependency() -> Dependency {
     DependencyBuilder::new()
         .name("pipereqwest".to_owned())
-        .version("0.1.2".to_owned())
+        .version("0.1.4".to_owned())
         .modules(vec!["pipereqwest::*".to_owned()])
         .build()
 }
@@ -252,7 +252,7 @@ pub(crate) fn default_reqwest_dependency() -> Dependency {
 pub(crate) fn default_rocksdb_dependency() -> Dependency {
     DependencyBuilder::new()
         .name("piperocksdb".to_owned())
-        .version("0.1.2".to_owned())
+        .version("0.1.4".to_owned())
         .modules(vec!["piperocksdb::*".to_owned()])
         .build()
 }
@@ -260,7 +260,7 @@ pub(crate) fn default_rocksdb_dependency() -> Dependency {
 pub(crate) fn default_warp_dependency() -> Dependency {
     DependencyBuilder::new()
         .name("pipewarp".to_owned())
-        .version("0.1.2".to_owned())
+        .version("0.1.4".to_owned())
         .modules(vec!["pipewarp::*".to_owned()])
         .build()
 }
@@ -304,7 +304,7 @@ pub(crate) fn default_sqs_dependency() -> Dependency {
 pub(crate) fn default_mqtt_dependency() -> Dependency {
     DependencyBuilder::new()
         .name("pipemqtt".to_owned())
-        .version("0.1.2".to_owned())
+        .version("0.1.4".to_owned())
         .modules(vec!["pipemqtt::*".to_owned()])
         .build()
 }
@@ -312,7 +312,7 @@ pub(crate) fn default_mqtt_dependency() -> Dependency {
 pub(crate) fn default_amqp_dependency() -> Dependency {
     DependencyBuilder::new()
         .name("pipeamqp".to_owned())
-        .version("0.1.0".to_owned())
+        .version("0.1.2".to_owned())
         .modules(vec!["pipeamqp::*".to_owned()])
         .build()
 }
